@@ -27,6 +27,7 @@
 #include <QDateTime>
 #include <QDebug>
 #include <QUrl>
+#include <kpublictransport/journey.h>
 
 bool PublicTransport::isTrainMode(KPublicTransport::Line::Mode mode)
 {
@@ -643,4 +644,30 @@ bool PublicTransport::isSameStopoverForLayout(const KPublicTransport::Stopover &
     return lhsPlatform == rhsPlatform;
 }
 
+QList<QGeoCoordinate>PublicTransport::pathToGeoCoordinates(const KPublicTransport::JourneySection &jny)
+{
+    QList<QGeoCoordinate> result;
+    if (jny.path().isEmpty()) {
+        result.push_back({jny.departure().stopPoint().latitude(), jny.departure().stopPoint().longitude()});
+        for (const auto &s : jny.intermediateStops()) {
+            if (!s.stopPoint().hasCoordinate()) {
+                continue;
+            }
+
+            result.push_back({s.stopPoint().latitude(), s.stopPoint().longitude()});
+        }
+        result.push_back({jny.arrival().stopPoint().latitude(), jny.arrival().stopPoint().longitude()});
+        return result;
+    }
+
+    for (const auto &section : jny.path().sections()) {
+        const auto path = section.path();
+        for (const auto &p : path) {
+            result.push_back({p.y(), p.x()});
+        }
+    }
+
+    return result;
+}
+
 #include "moc_publictransport.cpp"
