@@ -19,6 +19,8 @@
 #include <KPublicTransport/Line>
 #include <KPublicTransport/Manager>
 
+#include <QGeoCoordinate>
+
 namespace KPublicTransport {
 class Journey;
 class JourneySection;
@@ -129,6 +131,11 @@ public:
      */
     [[nodiscard]] static bool isSameStopoverForLayout(const KPublicTransport::Stopover &lhs, const KPublicTransport::Stopover &rhs);
 
+    /** Convert a KPublicTransport::JourneySection path into a QGeoCoordinate list for consumption by a QtLocation
+     *  map item.
+     */
+    Q_INVOKABLE [[nodiscard]] static QList<QGeoCoordinate> pathToGeoCoordinates(const KPublicTransport::JourneySection &jny);
+
 private:
     // for use by the template code
     static QString idenfitierFromLocation(const KPublicTransport::Location &loc);
